@@ -1,6 +1,6 @@
 package TestLink::API;
 {
-    $TestLink::API::VERSION = '0.005';
+    $TestLink::API::VERSION = '0.006';
 }
 
 
@@ -1488,8 +1488,14 @@ L<XMLRPC::Lite>
 
 =head1 AUTHOR
 
-George Baugh (george@troglodyne.net)
+George Baugh <teodesian@cpan.org>
 
 =head1 SPECIAL THANKS
 
 cPanel, Inc. graciously funded the initial work on this project.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by George S. Baugh.
+
+This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.
